@@ -269,5 +269,110 @@ test_that("fapply10: fapply() works as expected with single item vector lookup."
   expect_equal(res, re)
 })
 
+test_that("fapply11: format_quarter() works as expected.", {
+  
+  
+  v1 <- as.Date(c("2000-01-15", "2025-03-15", "2000-04-15", "2025-06-15", 
+                  "2000-07-15", "2025-09-15", "2000-10-15", "2025-12-15", 
+                  "2025-12-32", "2000-20-59"))
+
+  f1 <- format(v1, "%Y-%q")  
+  
+  res <- format_quarter(v1, f1, "%Y-%q")
+  
+  res
+  
+  expect_equal(all(res[1:8] == c("2000-1", "2025-1", "2000-2", "2025-2", "2000-3", "2025-3",
+                          "2000-4", "2025-4")), TRUE)
+  
+  f2 <- format(v1, "%Y-%Q")  
+  
+  res2 <- format_quarter(v1, f2, "%Y-%Q")
+  
+  res2
+  
+  expect_equal(all(res2[1:8] == c("2000-Q1", "2025-Q1", "2000-Q2", "2025-Q2", "2000-Q3", 
+                           "2025-Q3", "2000-Q4", "2025-Q4")), TRUE)
+
+})
+
+test_that("fapply12: fapply with quarter works as expected.", {
+  
+  
+  v1 <- as.Date(c("2000-01-15", "2025-03-15", "2000-04-15", "2025-06-15", 
+                  "2000-07-15", "2025-09-15", "2000-10-15", "2025-12-15", 
+                  "2025-12-32", "2000-20-59"))
+  
+  res1 <- fapply(v1, "%y-%q")
+  
+  print(res1)
+  
+  expect_equal(all(res1[1:8] == c("00-1", "25-1", "00-2","25-2", "00-3", "25-3", "00-4",
+                          "25-4")), TRUE)
+  
+  
+  res2 <- fapply(v1, "%Y-%Q")
+  
+  res2
+  
+  print(res2)
+  
+  expect_equal(all(res2[1:8] == c("2000-Q1", "2025-Q1", "2000-Q2","2025-Q2", "2000-Q3", 
+                          "2025-Q3", 
+                          "2000-Q4",
+                          "2025-Q4")), TRUE)
+  
+  
+  res3 <- fapply(v1, "%q")
+  
+  res3
+  
+  print(res3)
+  
+  expect_equal(all(res3[1:8] == c("1", "1", "2","2", "3", "3", "4",
+                           "4")), TRUE)
+  
+  res4 <- fapply(Sys.time(), "%Q")
+  
+  res4
+  
+  print(res4)
+  
+  # No error
+  expect_equal(TRUE, TRUE)
+  
+})
+
+# fapply(Sys.Date(), "%Y-%Q-%d")
+
+# fapply(Sys.Date(), "%Y-%q-%d")
 
 
+test_that("fapply13: fapply with quarter and date works as expected.", {
+  
+  
+  v1 <- as.Date(c("2000-01-15", "2025-03-15", "2000-04-15", "2025-06-15", 
+                  "2000-07-15", "2025-09-15", "2000-10-15", "2025-12-15", 
+                  "2025-12-32", "2000-20-59"))
+  
+  res1 <- fapply(v1, "%y-%q-%d")
+  
+  
+  
+  expect_equal(all(res1[1:8] == c("00-1-15", "25-1-15", "00-2-15","25-2-15", "00-3-15", 
+                           "25-3-15", "00-4-15", "25-4-15")), TRUE)
+  
+  
+  res2 <- fapply(v1, "%Y-%Q-%d")
+  
+  format(v1, format = "%Y-%Q-%d")
+  
+  res2
+  
+  expect_equal(all(res2[1:8] == c("2000-Q1-15", "2025-Q1-15", "2000-Q2-15","2025-Q2-15", "2000-Q3-15", 
+                           "2025-Q3-15", 
+                           "2000-Q4-15",
+                           "2025-Q4-15")), TRUE)
+  
+  
+})
